@@ -16,9 +16,9 @@
 %
 %     'bootwild (y)' performs a null hypothesis significance test for the
 %     mean of y being equal to 0. This function implements wild bootstrap-t
-%     resampling of Webb's 6-point distribution of the residuals, and computes
-%     p-values after imposing the null hypothesis (H0) [1-4]. The following
-%     statistics are printed to the standard output:
+%     resampling of Webb's 6-point distribution of the residuals and computes
+%     confidence intervals and p-values [1-4]. The following statistics are
+%     printed to the standard output:
 %        - original: the mean of the data vector y
 %        - std_err: heteroscedasticity-consistent standard error(s) (HC0)
 %        - CI_lower: lower bound(s) of the 95% bootstrap-t confidence interval
@@ -26,11 +26,11 @@
 %        - tstat: Student's t-statistic
 %        - pval: two-tailed p-value(s) for the parameter(s) being equal to 0
 %        - fpr: minimum false positive risk for the corresponding p-value
-%          By default, the confidence intervals are symmetric, two-sided
-%          bootstrap-t confidence intervals. The p-values are computed
-%          following both of the guidelines by Hall and Wilson [5]. The minimum
-%          false positive risk (FPR) is computed according to the Sellke-Berger
-%          approach as described in [6,7].
+%          By default, the confidence intervals are symmetric bootstrap-t
+%          confidence intervals. The p-values are computed following both of
+%          the guidelines by Hall and Wilson [5]. The minimum false positive
+%          risk (FPR) is computed according to the Sellke-Berger approach as
+%          as described in [6,7].
 %
 %     'bootwild (y, X)' also specifies the design matrix (X) for least squares
 %     regression of y on X. X should be a column vector or matrix the same
@@ -69,8 +69,8 @@
 %                  upper bounds of ASYMMETRIC bootstrap-t confidence interval(s)
 %                  as 100*(ALPHA(1))% and 100*(ALPHA(2))% respectively. For
 %                  example, [.025, .975] for a 95% confidence interval.
-%        The default value of ALPHA is the scalar: 0.05, for a symmetric 95%
-%        bootstrap-t confidence interval.
+%        The default value of ALPHA is the scalar: 0.05, for symmetric 95% 
+%        bootstrap-t confidence interval(s).
 %
 %     'bootwild (y, X, ..., NBOOT, ALPHA, SEED)' initialises the Mersenne
 %     Twister random number generator using an integer SEED value so that
@@ -112,7 +112,7 @@
 %  [7] Sellke, Bayarri and Berger (2001) Calibration of p-values for Testing
 %        Precise Null Hypotheses. Am Stat. 55(1), 62-71
 %
-%  bootwild (version 2024.05.17)
+%  bootwild (version 2024.05.23)
 %  Author: Andrew Charles Penn
 %  https://www.researchgate.net/profile/Andrew_Penn/
 %
@@ -476,7 +476,7 @@ function print_output (stats, nboot, alpha, p, L, method)
                        ' bootstrap-t interval\n'));
       coverage = 100 * abs (alpha(2) - alpha(1));
       fprintf (cat (2, ' Nominal coverage (and the percentiles used):', ...
-                       ' %.3g%% (%.1f%%, %.1f%%)\n', coverage, 100 * alpha(:)));
+                       ' %.3g%% (%.1f%%, %.1f%%)\n'), coverage, 100 * alpha(:)');
     else
       % prob is a two-tailed probability
       fprintf (cat (2, ' Confidence interval (CI) type: Symmetric', ...
@@ -523,7 +523,7 @@ end
 %! % Input univariate dataset
 %! heights = [183, 192, 182, 183, 177, 185, 188, 188, 182, 185].';
 %!
-%! % Test statistics and p-values (H0 = 0)
+%! % Compute test statistics, confidence intervals and p-values (H0 = 0)
 %! bootwild (heights);
 %!
 %! % Please be patient, the calculations will be completed soon...
@@ -541,7 +541,7 @@ end
 %!     168.0,170.0,178.0,182.0,180.0,183.0,178.0,182.0,188.0,175.0,179.0,...
 %!     183.0,192.0,182.0,183.0,177.0,185.0,188.0,188.0,182.0,185.0]';
 %!
-%! % Compute test statistics and p-values
+%! % Compute test statistics, confidence intervals and p-values (H0 = 0)
 %! bootwild (y, X);
 %!
 %! % Please be patient, the calculations will be completed soon...
